
.. filesysobjects documentation master file, created by
   sphinx-quickstart on `date`.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

'filesysobjects' - Filesystem Objects
=====================================

The 'filesysobjects' package provides utilities for the application of
basic object oriented features onto filesystems.
This includes basic coverage of the 'inspect' package for the simplified
gathering of information on packages, modules, and files.

The provided feature modules comprise the following list.
For code examples refer to 'filesysobjects.UseCases'.

* `FileSysObjects <pyfilesysobjects.html>`_ : Manage branches of filesystem structures with support of basic file inheritance - *filesysobjects.FileSysObjects*.

* `PySourceInfo <pysourceinfo.html>`_ : Provides runtime type information information on Python source components: packages, modules, and callers  - *filesysobjects.PySourceInfo*.

.. toctree::
   :maxdepth: 3

   filesysobjects
   pysourceinfo
   UseCases
   tests

* setup.py

  For help on extensions to standard options call onlinehelp:: 

    python setup.py --help-filesysobjects



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Resources
=========

For available downloads refer to:

* Python Package Index: https://pypi.python.org/pypi/filesysobjects

* Sourceforge.net: https://sourceforge.net/projects/filesysobjects/

* github.com: https://github.com/ArnoCan/filesysobjects/

For Licenses refer to enclosed documents:

* Artistic-License-2.0(base license): `ArtisticLicense20.html <_static/ArtisticLicense20.html>`_

* Forced-Fairplay-Constraints(amendments): `licenses-amendments.txt <_static/licenses-amendments.txt>`_ / `Protect OpenSource Authors <http://xkcd.com/1303/>`_

